import * as Cesium from 'cesium';
import 'cesium/Build/Cesium/Widgets/widgets.css';

// Cesium.Ion.defaultAccessToken =
//   'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJqdGkiOiJiYjZmMWM4Ny01YzQ4LTQ3MzUtYTI5Mi1hNTgyNjdhMmFiMmMiLCJpZCI6NjIwMjgsImlhdCI6MTYyNjY3MTMxNX0.5SelYUyzXWRoMyjjFvmFIAoPtWlJPQMjsVl2e_jQe-c';

export function cesium_init() {
  // 复写原型方法 用于timeline组件日期格式化；
  // @ts-expect-error node_modules/@cesium/widgets/Source/Timeline/Timeline.js
  Cesium.Timeline.prototype.makeLabel = function (time) {
    let minutes = 0 - new Date().getTimezoneOffset();
    let dataZone8 = Cesium.JulianDate.addMinutes(time, minutes, new Cesium.JulianDate());
    return Cesium.JulianDate.toIso8601(dataZone8).slice(0, 19);
  };

  // cesium-viewer-bottom

  const viewer = new Cesium.Viewer('cesiumContainer', {
    /* animationContainer: !true, */
    /* timelineContainer: true, */
    /* bottomContainer: document.createElement('p'), // The DOM element or ID that will contain the bottomContainer.  If not specified, the bottomContainer is added to the widget itself. */
    shouldAnimate: true,
    // globe: false, // 地球
    baseLayerPicker: true,
    homeButton: true, // Home按钮
    fullscreenButton: !true, // 全屏按钮
    geocoder: true, // = IonGeocodeProviderType.DEFAULT] - 在使用Geocoder小部件进行搜索时使用的地理编码服务或服务。如果设置为false，则不会创建Geocoder小部件。
    infoBox: true, // InfoBox小部件。
    navigationHelpButton: !true, // 是否显示导航帮助按钮
    projectionPicker: !true, // 投影选择器
    sceneModePicker: true, // 是否显示场景模式选择器(2D/3D切换)
    animation: true, // 是否创建动画小部件
    timeline: true, // If set to false, the Timeline widget will not be created.
    selectionIndicator: true,
    requestRenderMode: !true, // 如果为真，渲染帧将仅在场景内部发生变化时需要时发生。启用此功能可以减少应用程序的CPU/GPU使用率，并在移动设备上节省更多电量，但在此模式下需要使用{@link Scene#requestRender}显式渲染新帧。在API的其他部分对场景进行更改后，在许多情况下都需要这样做。请参阅{@link https://cesium.com/blog/2018/01/24/cesium-scene-rendering-performance/|使用显式渲染提高性能}。
    showRenderLoopErrors: true, // 如果为真，当发生渲染循环错误时，此小部件将自动向用户显示包含错误的HTML面板。
    orderIndependentTranslucency: false, // 顺序无关透明度
    shadows: true, // Determines if shadows are cast by light sources.
  });
  /* if ($__DEV__) */ viewer.scene.debugShowFramesPerSecond = true;

  // 时间格式化
  let minutes = 0 - new Date().getTimezoneOffset(); // 0 - (-480);
  viewer.animation.viewModel.timeFormatter = function (date, _viewModel) {
    let dataZone8 = Cesium.JulianDate.addMinutes(date, minutes, new Cesium.JulianDate());
    return Cesium.JulianDate.toIso8601(dataZone8).slice(11, 19);
  };
  viewer.animation.viewModel.dateFormatter = function (date, _viewModel) {
    let dataZone8 = Cesium.JulianDate.addMinutes(date, minutes, new Cesium.JulianDate());
    return Cesium.JulianDate.toIso8601(dataZone8).slice(0, 10);
  };

  //高德卫星地图
  let gaoDeSatelliteImgLayer = new Cesium.UrlTemplateImageryProvider({
    url: 'https://webst02.is.autonavi.com/appmaptile?style=6&x={x}&y={y}&z={z}',
    minimumLevel: 3,
    maximumLevel: 18,
    tilingScheme: new Cesium.WebMercatorTilingScheme(),
  });

  const customLayerViewModel = new Cesium.ProviderViewModel({
    name: '高德地图',
    iconUrl: 'gaodeImage.png',
    tooltip: '高德地图',
    category: 'Cesium ion', // 或 'Other 、Cesium ion'、'Bing Maps' 等
    creationFunction: function () {
      return gaoDeSatelliteImgLayer;
    },
  });
  // 设置高德地图为默认图层
  viewer.baseLayerPicker.viewModel.imageryProviderViewModels.unshift(customLayerViewModel);
  const selectedViewModel = viewer.baseLayerPicker.viewModel.imageryProviderViewModels[0];
  viewer.baseLayerPicker.viewModel.selectedImagery = selectedViewModel;

  Cesium.Camera.DEFAULT_VIEW_RECTANGLE = Cesium.Rectangle.fromDegrees(
    75.0, // 西经
    10.0, // 南纬
    140.0, // 东经
    60.0, // 北纬
  );

  return viewer;
}
